@@ -1,7 +1,9 @@
-from django.db.models import get_model, Model
+from copy import deepcopy
 from logging import getLogger
-from django.db.models.sql.constants import LOOKUP_SEP
+
 from django.core.exceptions import FieldError
+from django.db.models import get_model, Model
+from django.db.models.sql.constants import LOOKUP_SEP
 from django.http import HttpResponse
 
 from adrest.forms import PartitialForm
@@ -79,7 +81,7 @@ class HandlerMixin(object):
         return self.paginate(request, self.get_queryset(request, **resources))
 
     def post(self, request, **resources):
-        form = self.form(data=request.data, **resources)
+        form = self.form(data=deepcopy(request.data), **resources)
         if form.is_valid():
             return form.save()
         raise HttpError(form.errors.as_text(), status=status.HTTP_400_BAD_REQUEST)
@@ -89,7 +91,7 @@ class HandlerMixin(object):
         if not instance:
             raise HttpError("Bad request", status=status.HTTP_404_NOT_FOUND)
 
-        form = self.form(data=request.data, instance=instance, **resources)
+        form = self.form(data=deepcopy(request.data), instance=instance, **resources)
         if form.is_valid():
             return form.save()
 
